@@ -1,20 +1,13 @@
-# Configuration file for the Sphinx documentation builder.
-#
-# This file only contains a selection of the most common options. For a full
-# list see the documentation:
-# https://www.sphinx-doc.org/en/master/usage/configuration.html
-
+from importlib import metadata
 import re
 
-import venvs
-
 # -- Project information -----------------------------------------------------
 
 project = "venvs"
 author = "Julian Berman"
 copyright = "2015, " + author
 
-release = venvs.__version__
+release = metadata.version("venvs")
 version = release.partition("-")[0]
 
 
@@ -38,7 +31,7 @@ templates_path = ["_templates"]
 # This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
-# The reST default role (used for this markup: `text`) to use for all documents.
+# The reST default role (used for this markup: `text`) to use for all documents
 default_role = "any"
 
 
@@ -47,7 +40,7 @@ default_role = "any"
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = "alabaster"
+html_theme = "furo"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
