@@ -63,8 +63,9 @@ class ConfiguredVirtualEnv(object):
             links = (
                 each.partition(":") for each in config_dict.get(section, [])
             )
+            # target -> source, since it's target names that must be unique
             kwargs[section.replace("-", "_")] = pmap(
-                (name, to or name) for name, _, to in links
+                (to or name, name) for name, _, to in links
             )
         return cls(name=name, **kwargs)
 
@@ -82,7 +83,7 @@ class ConfiguredVirtualEnv(object):
     def matches_existing(self, virtualenv, filesystem):
         try:
             existing = json.loads(
-                filesystem.get_contents(virtualenv.path / "installed.json")
+                filesystem.get_contents(virtualenv.path / "installed.json"),
             )
         except (ValueError, filesystems.exceptions.FileNotFound):
             return False
@@ -126,7 +127,7 @@ class Config(object):
             ConfiguredVirtualEnv.from_dict(
                 name=name,
                 config_dict=config,
-                bundles=self._contents["bundle"]
+                bundles=self._contents["bundle"],
             ) for name, config in self._contents["virtualenv"].items()
         )
 
