@@ -29,7 +29,10 @@ def _install_into_virtualenv(
     if not packages and not requirements:
         return
     things = list(
-        chain(packages, *(("-r", requirement) for requirement in requirements))
+        chain(
+            packages,
+            *(("-r", requirement) for requirement in requirements),
+        ),
     )
     subprocess.check_call(
         [
@@ -152,6 +155,7 @@ _ROOT = click.option(
 _FILESYSTEM = click.option(
     "--filesystem",
     default=filesystems.native.FS(),
+    type=lambda value: value,
 )
 _LINK_DIR = click.option(
     "--link-dir",
