@@ -37,8 +37,26 @@ class TestConfig(TestCase):
             list(config), [
                 _config.ConfiguredVirtualEnv(
                     name="a",
-                    link={"foo": "foo", "bar": "bar", "baz": "quux"},
-                    link_module={"spam": "spam", "eggs": "cheese"},
+                    link={"foo": "foo", "bar": "bar", "quux": "baz"},
+                    link_module={"spam": "spam", "cheese": "eggs"},
+                ),
+            ],
+        )
+
+    def test_links_to_same_binary(self):
+        config = _config.Config.from_string(
+            """
+            [virtualenv.a]
+            link = ["foo", "foo:bar"]
+            link-module = ["spam", "spam:cheese"]
+            """,
+        )
+        self.assertEqual(
+            list(config), [
+                _config.ConfiguredVirtualEnv(
+                    name="a",
+                    link={"foo": "foo", "bar": "foo"},
+                    link_module={"spam": "spam", "cheese": "spam"},
                 ),
             ],
         )
@@ -191,8 +209,7 @@ class TestConfig(TestCase):
         config = _config.Config()
         added = config.add("a", install=["foo", "bar"], link=["baz"])
         self.assertEqual(
-            (list(config), list(added)),
-            (
+            (list(config), list(added)), (
                 [], [
                     _config.ConfiguredVirtualEnv(
                         name="a",
@@ -200,7 +217,7 @@ class TestConfig(TestCase):
                         link={"baz": "baz"},
                     ),
                 ],
-            )
+            ),
         )
 
     def test_add_empty(self):
